@@ -1,6 +1,8 @@
 def main():
+  import os
   import appyter.ext.multiprocessing
   # load dotenv if present
+  os.environ['PYTHONUTF8'] = '1'
   from dotenv import load_dotenv
   load_dotenv()
   # load everything permitting injection to cli
