@@ -25,8 +25,9 @@ class SubprocessExecutor(AbstractExecutor):
       job['ipynb'],
       stderr=sys.stderr,
       env=dict(
+        os.environ,
+        { k: v for k, v in os.environ.items() if not k.startswith('APPYTER_') },
         PYTHONPATH=':'.join(sys.path),
-        PATH=os.environ['PATH'],
       ),
     ):
       yield msg, done
