@@ -6,8 +6,10 @@ logger = logging.getLogger(__name__)
 
 from appyter.ext.socketio.forwarding import ForwardingMixin
 from appyter.ext.socketio.priority_queued_emit import PriorityQueuedEmitMixin
+from appyter.ext.socketio.chunked_emit import ChunkedEmitMixin
 
 class AsyncClient(
+  ChunkedEmitMixin,
   ForwardingMixin,
   PriorityQueuedEmitMixin,
   socketio.AsyncClient,
